@@ -29,11 +29,12 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
-                            '-Werror=lto-type-mismatch -Werror=strict-aliasing '
-                            '-flto -ffat-lto-objects -flto -fuse-linker-plugin '
-                            '-ffat-lto-objects -g -std=c99 -Wextra '
-                            '-Wno-unused-result -Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic '
+                            '-Werror=odr -Werror=lto-type-mismatch '
+                            '-Werror=strict-aliasing -flto -ffat-lto-objects '
+                            '-flto -fuse-linker-plugin -ffat-lto-objects -g '
+                            '-std=c99 -Wextra -Wno-unused-result '
+                            '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
@@ -50,8 +51,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.10.18_p2' "
-                "'--htmldir=/usr/share/doc/python-3.10.18_p2/html' "
+                "'--docdir=/usr/share/doc/python-3.10.19' "
+                "'--htmldir=/usr/share/doc/python-3.10.19/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -69,8 +70,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18/coverage.info',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18/lcov-report',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.10.19/work/Python-3.10.19/coverage.info',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.10.19/work/Python-3.10.19/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
@@ -668,7 +669,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                             '-pipe -march=x86-64-v3 -Werror=odr '
+                             '-pipe -march=x86-64 -mtune=generic -Werror=odr '
                              '-Werror=lto-type-mismatch '
                              '-Werror=strict-aliasing -flto -ffat-lto-objects '
                              '-flto -fuse-linker-plugin -ffat-lto-objects -g '
@@ -681,7 +682,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
+ 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr '
                      '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
                      '-ffat-lto-objects -flto -fuse-linker-plugin '
                      '-ffat-lto-objects -g -std=c99 -Wextra -Wno-unused-result '
@@ -691,13 +692,13 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe '
-                   '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
-                   '-Werror=strict-aliasing -flto -ffat-lto-objects -flto '
-                   '-fuse-linker-plugin -ffat-lto-objects -g -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include '
+                   '-march=x86-64 -mtune=generic -Werror=odr '
+                   '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                   '-ffat-lto-objects -flto -fuse-linker-plugin '
+                   '-ffat-lto-objects -g -std=c99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                     '-Werror=odr -Werror=lto-type-mismatch '
@@ -714,7 +715,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe '
-                        '-march=x86-64-v3 -Werror=odr '
+                        '-march=x86-64 -mtune=generic -Werror=odr '
                         '-Werror=lto-type-mismatch -Werror=strict-aliasing '
                         '-flto -ffat-lto-objects -flto -fuse-linker-plugin '
                         '-ffat-lto-objects -g -std=c99 -Wextra '
@@ -731,7 +732,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'x86_64-pc-linux-gnu-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.19/work/Python-3.10.19',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -773,10 +774,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.19/work/Python-3.10.19 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.19/work/Python-3.10.19 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -804,8 +805,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.10.19/work/Python-3.10.19',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.10.19/work/Python-3.10.19',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
